@@ -1,10 +1,10 @@
 # pylint: disable=bare-except,broad-except
 import logging
-import time
+from datetime import datetime
 
 from pyosmo.config import OsmoConfig
 from pyosmo.history.history import OsmoHistory
-from pyosmo.model import Model, TestStep
+from pyosmo.model import OsmoModelCollector, TestStep
 
 logger = logging.getLogger('osmo')
 
@@ -15,13 +15,13 @@ class Osmo(OsmoConfig):
     def __init__(self, model: object = None):
         """ Osmo need at least one model to work """
         super().__init__()
-        self.model = Model()
+        self.model = OsmoModelCollector()
         if model:
             self.add_model(model)
         self.history = OsmoHistory()
 
     @staticmethod
-    def _check_model(model):
+    def _check_model(model: object):
         """ Check that model is valid"""
         if not hasattr(model, '__class__'):
             raise Exception("Osmo model need to be instance of model, not just class")
@@ -39,12 +39,12 @@ class Osmo(OsmoConfig):
         :return:
         """
         logger.debug(f'Run step: {step}')
-        start_time = time.time()
+        start_time = datetime.now()
         try:
             step.execute()
-            self.history.add_step(step, time.time() - start_time)
+            self.history.add_step(step, datetime.now() - start_time)
         except Exception as error:
-            self.history.add_step(step, time.time() - start_time, error)
+            self.history.add_step(step, datetime.now() - start_time, error)
             raise error
 
     def run(self):
@@ -69,8 +69,7 @@ class Osmo(OsmoConfig):
                 while True:
                     # Use algorithm to select the step
                     self.model.execute_optional('before')
-                    step = self.algorithm.choose(self.history,
-                                                 self.model.available_steps())
+                    step = self.algorithm.choose(self.history, self.model.available_steps)
                     self.model.execute_optional(f'pre_{step}')
                     try:
                         self._run_step(step)
